# The Python OCSF Library

[![PyPI](https://img.shields.io/pypi/v/py-ocsf.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/py-ocsf.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/py-ocsf)][pypi status]
[![License](https://img.shields.io/pypi/l/py-ocsf)][license]

[![Read the documentation at https://py-ocsf.readthedocs.io/](https://img.shields.io/readthedocs/py-ocsf/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/river-studio-net/py-ocsf/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/river-studio-net/py-ocsf/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Ruff codestyle][ruff badge]][ruff project]

[pypi status]: https://pypi.org/project/py-ocsf/
[read the docs]: https://py-ocsf.readthedocs.io/
[tests]: https://github.com/river-studio-net/py-ocsf/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/river-studio-net/py-ocsf
[pre-commit]: https://github.com/pre-commit/pre-commit
[ruff badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
[ruff project]: https://github.com/charliermarsh/ruff

## Features

- TODO

## Requirements

- TODO

## Installation

You can install _The Python OCSF Library_ via [pip] from [PyPI]:

```console
$ pip install py-ocsf
```

## Usage

Please see the [Command-line Reference] for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [GNU General Public License v3.0 or higher][license],
_The Python OCSF Library_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

## Credits

This project was generated from [@cjolowicz]'s [uv hypermodern python cookiecutter] template.

[@cjolowicz]: https://github.com/cjolowicz
[pypi]: https://pypi.org/
[uv hypermodern python cookiecutter]: https://github.com/bosd/cookiecutter-uv-hypermodern-python
[file an issue]: https://github.com/river-studio-net/py-ocsf/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/river-studio-net/py-ocsf/blob/main/LICENSE
[contributor guide]: https://github.com/river-studio-net/py-ocsf/blob/main/CONTRIBUTING.md
[command-line reference]: https://py-ocsf.readthedocs.io/en/latest/usage.html
